Documentation
¶
Index ¶
Constants ¶
This section is empty.
Variables ¶
This section is empty.
Functions ¶
func NewMonitoringStore ¶
func NewMonitoringStore( resourceType string, createHandlers []ObjCreateFunc, updateHandlers []ObjUpdateFunc, deleteHandlers []ObjDeleteFunc, resourceTracker ResourceTracker, intervalRecorder IntervalRecorder, ) *monitoringStore
Types ¶
type IntervalRecorder ¶
type IntervalRecorder interface {
AddIntervals(intervals ...monitorapi.Interval)
}
type ObjCreateFunc ¶
type ObjCreateFunc func(obj interface{}) []monitorapi.Interval
type ObjDeleteFunc ¶
type ObjDeleteFunc func(obj interface{}) []monitorapi.Interval
type ObjUpdateFunc ¶
type ObjUpdateFunc func(obj, oldObj interface{}) []monitorapi.Interval
type ResourceTracker ¶
type ResourceTracker interface {
// RecordResource stores a resource for later serialization. Deletion is not tracked, so this can be used
// to determine the final state of resource that are deleted in a namespace.
// Annotations are added to indicate number of updates and the number of recreates.
RecordResource(resourceType string, obj runtime.Object)
}
Click to show internal directories.
Click to hide internal directories.